==> open-xchange-core_7.10.1.orig.tar.bz2: open-xchange-core-7.10.1/com.openexchange.groupware.tools/src/com/openexchange/groupware/tools/mappings/json/DateMapping.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.groupware.tools.mappings.json;

import java.util.Date;
import java.util.TimeZone;
import org.json.JSONException;
import org.json.JSONObject;
import com.openexchange.exception.OXException;
import com.openexchange.session.Session;

/**
 * {@link DateMapping} - JSON specific mapping implementation for Dates.
 *
 * @param <O> the type of the object
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public abstract class DateMapping<O> extends DefaultJsonMapping<Date, O> {

    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(DateMapping.class);

	/**
	 * Initializes a new {@link DateMapping}.
	 *
	 * @param ajaxName The AJAX name
	 * @param columnID The column identifier
	 */
    public DateMapping(final String ajaxName, final Integer columnID) {
		super(ajaxName, columnID);
	}

	@Override
	public void deserialize(JSONObject from, O to) throws JSONException, OXException {
	    final String ajaxName = getAjaxName();
        if (from.isNull(ajaxName)) {
            set(to, null);
        } else {
            final Object object = from.get(ajaxName);
            if (object instanceof Number) {
                set(to, new Date(((Number) object).longValue()));
            } else if (null != object) {
                final String sObject = object.toString();
                if (!com.openexchange.java.Strings.isEmpty(sObject)) {
                    try {
                        set(to, new Date(Long.parseLong(sObject)));
                    } catch (final NumberFormatException e) {
                        throw new JSONException("JSONObject[\""+ajaxName+"\"] is not a number: " + object);
                    }
                }
            } else {
                throw new JSONException("JSONObject[\""+ajaxName+"\"] is not a number: " + object);
            }
        }
	}

	@Override
	public Object serialize(O from, TimeZone timeZone, Session session) throws JSONException {
		final Date value = this.get(from);
		return null == value ? JSONObject.NULL : Long.valueOf(value.getTime());
	}

}

==> open-xchange-core_7.10.4.orig.tar.bz2: open-xchange-core-7.10.4/com.openexchange.groupware.tools/src/com/openexchange/groupware/tools/mappings/json/DateMapping.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.groupware.tools.mappings.json;

import java.util.Date;
import java.util.TimeZone;
import org.json.JSONException;
import org.json.JSONObject;
import com.openexchange.exception.OXException;
import com.openexchange.session.Session;

/**
 * {@link DateMapping} - JSON specific mapping implementation for Dates.
 *
 * @param <O> the type of the object
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public abstract class DateMapping<O> extends DefaultJsonMapping<Date, O> {

    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(DateMapping.class);

	/**
	 * Initializes a new {@link DateMapping}.
	 *
	 * @param ajaxName The AJAX name
	 * @param columnID The column identifier
	 */
    public DateMapping(final String ajaxName, final Integer columnID) {
		super(ajaxName, columnID);
	}

	@Override
	public void deserialize(JSONObject from, O to) throws JSONException, OXException {
	    final String ajaxName = getAjaxName();
        if (from.isNull(ajaxName)) {
            set(to, null);
        } else {
            final Object object = from.get(ajaxName);
            if (object instanceof Number) {
                set(to, new Date(((Number) object).longValue()));
            } else if (null != object) {
                final String sObject = object.toString();
                if (!com.openexchange.java.Strings.isEmpty(sObject)) {
                    try {
                        set(to, new Date(Long.parseLong(sObject)));
                    } catch (NumberFormatException e) {
                        throw new JSONException("JSONObject[\""+ajaxName+"\"] is not a number: " + object);
                    }
                }
            } else {
                throw new JSONException("JSONObject[\""+ajaxName+"\"] is not a number: " + object);
            }
        }
	}

	@Override
	public Object serialize(O from, TimeZone timeZone, Session session) throws JSONException {
		final Date value = this.get(from);
		return null == value ? JSONObject.NULL : Long.valueOf(value.getTime());
	}

}
